videocollection/videocollectionview/tsrc/testlistwidget/inc/testlistwidget.h
changeset 62 0e1e938beb1a
parent 52 e3cecb93e76a
--- a/videocollection/videocollectionview/tsrc/testlistwidget/inc/testlistwidget.h	Thu Sep 02 20:28:16 2010 +0300
+++ b/videocollection/videocollectionview/tsrc/testlistwidget/inc/testlistwidget.h	Fri Sep 17 08:30:05 2010 +0300
@@ -11,11 +11,11 @@
 *
 * Contributors:
 *
 * Description:   tester for methods in VideoSortFilterProxyModel
 *
 */
 
-// Version : %version: 27 %
+// Version : %version: 28 %
 
 #ifndef __TESTLISTWIDGET_H__
 #define __TESTLISTWIDGET_H__
@@ -28,7 +28,7 @@
 class DummyDataModel;
 class HbAbstractViewItem;
 class HbView;
-class VideoSortFilterProxyModel;
+class VideoProxyModelGeneric;
 class VideoCollectionWrapper;
 class HbMainWindow;
 class ListWidgetTester;
@@ -45,7 +45,7 @@
 public:
 
     void setRowCount(int count,
-        TModelType type = EModelTypeAllVideos,
+        VideoProxyModelGeneric *proxyModel = 0,
         VideoListDataModel *model = 0);
     
     // test functions for the test framework
@@ -11,11 +11,11 @@
 * Contributors:
 *
-* Description:   tester for methods in VideoSortFilterProxyModel
+* Description:   tester for methods in VideoProxyModelGeneric
 *
 */